@@ -128,13 +128,13 @@ rawOptsToWebOpts rawopts =
   checkWebOpts <$> do
     cliopts <- rawOptsToCliOpts rawopts
     let h = fromMaybe defhost $ maybestringopt "host" rawopts
-        p = fromMaybe defport $ maybeintopt "port" rawopts
+        p = fromMaybe defport $ maybeposintopt "port" rawopts
         b =
           maybe (defbaseurl h p) stripTrailingSlash $
           maybestringopt "base-url" rawopts
         caps' = join $ T.splitOn "," . T.pack <$> listofstringopt "capabilities" rawopts
         caps = case traverse capabilityFromText caps' of
-          Left e -> error' ("Unknown capability: " ++ T.unpack e)
+          Left e -> error' ("Unknown capability: " ++ T.unpack e)  -- PARTIAL:
           Right [] -> [CapView, CapAdd]
           Right xs -> xs
         sock = stripTrailingSlash <$> maybestringopt "socket" rawopts
